==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sesv2/kotlin/inputs/ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sesv2.kotlin.inputs

import com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationArn
 */
public data class ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs(
    public val applicationArn: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs> {
    override fun toJava():
        com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs =
        com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs.builder()
            .applicationArn(applicationArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs].
 */
@PulumiTagMarker
public class ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgsBuilder internal
constructor() {
    private var applicationArn: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("ongjhctraikpukgp")
    public suspend fun applicationArn(`value`: Output<String>) {
        this.applicationArn = value
    }

    /**
     * @param value
     */
    @JvmName("fgvajfuyngbnewpr")
    public suspend fun applicationArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationArn = mapped
    }

    internal fun build(): ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs =
        ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs(
            applicationArn = applicationArn ?: throw PulumiNullFieldException("applicationArn"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sesv2/kotlin/inputs/ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sesv2.kotlin.inputs

import com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationArn
 */
public data class ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs(
    public val applicationArn: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs> {
    override fun toJava(): com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs =
        com.pulumi.aws.sesv2.inputs.ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs.builder()
            .applicationArn(applicationArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs].
 */
@PulumiTagMarker
public class ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgsBuilder internal constructor() {
    private var applicationArn: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("oetwmctemgnobmre")
    public suspend fun applicationArn(`value`: Output<String>) {
        this.applicationArn = value
    }

    /**
     * @param value
     */
    @JvmName("xiijohyiwvdxgxub")
    public suspend fun applicationArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.applicationArn = mapped
    }

    internal fun build(): ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs =
        ConfigurationSetEventDestinationEventDestinationPinpointDestinationArgs(
            applicationArn = applicationArn ?: throw PulumiNullFieldException("applicationArn"),
        )
}
